@@ -11,15 +11,23 @@ test_that("pad_raster can handle all raster inputs", {
     expect_is(pad_raster(landscape_matrix, return_raster = FALSE, to_disk = FALSE), "list")
 })
 
-test_that("pad_raster can add more than one row", {
+test_that("pad_raster adds correct number of rows/cols", {
 
-    result <- landscapemetrics:::pad_raster(landscape,
-                                            pad_raster_cells = 5,
-                                            global = TRUE)[[1]]
+    result_a <- landscapemetrics:::pad_raster(landscape,
+                                              pad_raster_cells = 1,
+                                              global = TRUE)[[1]]
+
+    result_b <- landscapemetrics:::pad_raster(landscape,
+                                              pad_raster_cells = 5,
+                                              global = TRUE)[[1]]
+
+    # original landscape is 30 x 30 and adding 1 rows/cols in each direction
+    expect_equal(object = raster::nrow(result_a), expected = 32)
+    expect_equal(object = raster::nrow(result_a), expected = 32)
 
     # original landscape is 30 x 30 and adding 5 rows/cols in each direction
-    expect_equal(object = raster::nrow(result), expected = 40)
-    expect_equal(object = raster::nrow(result), expected = 40)
+    expect_equal(object = raster::nrow(result_b), expected = 40)
+    expect_equal(object = raster::nrow(result_b), expected = 40)
 })
 
 test_that("pad_raster can add different padding values", {
